==> deepin-screen-recorder_5.9.6.orig.tar.xz: deepin-screen-recorder-5.9.6/translations/deepin-screen-recorder_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.1">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Klicken Sie auf das Taskleistensymbol 
oder drücken Sie die Tastenkombination erneut, um die Aufnahme zu stoppen</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Aufnehmen</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Bildschirmaufnahme</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Bildschirmaufnahme</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Speichern fehlgeschlagen. Bitte speichern Sie in Ihrem Heimverzeichnis.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ansicht</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Bildschirmaufzeichnung beendet</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>Auswahlbereich</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Gespeichert unter %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorieren</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Zwischenablage</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Die Bildschirmaufnahme-Datei wird gespeichert, bitte warten ...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>Da der Fenstereffekt während des Vorgangs deaktiviert ist, muss die Aufnahme gestoppt werden</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Bildschirmaufnahme</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Rückgängig</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Beenden</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Ansicht</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Aufnahme beendet</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Gespeichert unter %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Aufnehmen</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Bildschirmaufzeichnung startet in %1 Sekunden</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Hier Text eingeben</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Start/Bildschirmaufnahme</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Beenden/Speichern</translation>
    </message>
    <message>
        <source>Drawing</source>
        <translation>Zeichnen</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Größenanpassung</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Schnellstart</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Fensteraufnahme</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Verzögerte Bildschirmaufnahme</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Volle Bildschirmaufnahme</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rechteck</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linie</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Stift</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Rückgängig</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Höhe nach oben erweitern</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Höhe nach unten erweitern</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Breite nach links erweitern</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Breite nach rechts erweitern</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Höhe von oben verkleinern</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Höhe von unten verkleinern</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Breite links verkleinern</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Breite rechts verkleinern</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Tastenkombinationen anzeigen</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Ton</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Tastendruck</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Aufnahme starten</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Optionen</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mouse</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>Unschärfe</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>Mosaik</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>Ton an</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Mikrofon</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>Systemklang</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>Ton aus</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>Tastendruck anzeigen</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>Tastendruck ausblenden</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>Webcam an</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>Webcam aus</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>Klick anzeigen</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Optionen</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>BpS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rechteck</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linie</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Pfeil</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Stift</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Speichern unter</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Schreibtisch</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Bilder</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Ordner</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Zwischenablage</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Zeiger anzeigen</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show Pointer</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation>Passe den Aufnahmebereich innerhalb von %1*%2 an, um einen besseren Videoeffekt zu erhalten</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Recordings</source>
        <translation>Aufnahmen</translation>
    </message>
</context>
</TS>

==> deepin-screen-recorder_5.10.15.orig.tar.xz: deepin-screen-recorder-5.10.15/translations/deepin-screen-recorder_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Klicken Sie auf das Taskleistensymbol 
oder drücken Sie die Tastenkombination erneut, um die Aufnahme zu stoppen</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>Drehen Sie Ihren Bildschirm während der Aufnahme nicht</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Aufnehmen</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Bildschirmaufnahme</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Bildschirmaufnahme</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Speichern fehlgeschlagen. Bitte speichern Sie in Ihrem Heimverzeichnis.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ansicht</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Bildschirmaufnahme beendet</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>Auswahlbereich</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Gespeichert unter %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorieren</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Zwischenablage</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Die Bildschirmaufnahme-Datei wird gespeichert, bitte warten ...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>Da der Fenstereffekt während des Vorgangs deaktiviert ist, muss die Aufnahme gestoppt werden</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Bildschirmaufnahme</translation>
    </message>
    <message>
        <source>The screenshot has been saved in the album</source>
        <translation>Die Bildschirmaufnahme wurde im Album gespeichert</translation>
    </message>
    <message>
        <source>Screenshot failed.</source>
        <translation>Bildschirmaufnahme fehlgeschlagen.</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Bildlaufaufnahme</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Rückgängig</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Beenden</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Ansicht</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Aufnahme beendet</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Gespeichert unter %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Aufnehmen</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Bildschirmaufzeichnung startet in %1 Sekunden</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>Hilfe holen.</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>Das Ende des Bildlaufbereichs erreicht</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>Die maximale Länge wurde erreicht</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>Drehen Sie Ihr Mausrad oder klicken Sie, um eine rollende Bildschirmaufnahme zu machen</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>Verlangsamen Sie die Bildlaufgeschwindigkeit</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Hier Text eingeben</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Start/Bildschirmaufnahme</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Beenden/Speichern</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Größenanpassung</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Schnellstart</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Fensteraufnahme</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Verzögerte Bildschirmaufnahme</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Volle Bildschirmaufnahme</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rechteck</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linie</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Stift</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Rückgängig</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Höhe nach oben erweitern</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Höhe nach unten erweitern</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Breite nach links erweitern</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Breite nach rechts erweitern</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Höhe von oben verkleinern</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Höhe von unten verkleinern</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Breite links verkleinern</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Breite rechts verkleinern</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Tastenkombinationen anzeigen</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Ton</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Tastendruck</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Aufnahme starten</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Optionen</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Start/Aufnahme</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Maus</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Werkzeuge</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Text extrahieren</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Bildlaufaufnahme</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>Unschärfe</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>Mosaik</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>Ton ein</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Mikrofon</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>Systemklang</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>Ton aus</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>Tastendruck anzeigen</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>Tastendruck ausblenden</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>Webcam an</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>Webcam aus</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>Klick anzeigen</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Optionen</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>BpS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 BpS</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 BpS</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 BpS</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 BpS</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 BpS</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rechteck</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linie</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Pfeil</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Stift</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Speichern unter</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Schreibtisch</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Bilder</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Ordner</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Zwischenablage</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Zeiger anzeigen</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Maus</translation>
    </message>
    <message>
        <source>Show Pointer</source>
        <translation>Zeiger anzeigen</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>Text extrahieren</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Bildlaufaufnahme</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation>Passe den Aufnahmebereich innerhalb von %1*%2 an, um einen besseren Videoeffekt zu erhalten</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exit</source>
        <translation>Beenden</translation>
    </message>
</context>
</TS>
